# stylelens-index
This is a API document for Index DB

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.0.1
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import stylelens_index 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import stylelens_index
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import stylelens_index
from stylelens_index.rest import ApiException
from pprint import pprint
# create an instance of the API class
api_instance = stylelens_index.IndexApi()
body = stylelens_index.Index() # Index | Index that needs to be added to the db.

try:
    # Added a new Index
    api_response = api_instance.add_index(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling IndexApi->add_index: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://index.stylelens.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*IndexApi* | [**add_index**](docs/IndexApi.md#add_index) | **POST** /indexes | Added a new Index
*IndexApi* | [**get_index_by_index_id**](docs/IndexApi.md#get_index_by_index_id) | **GET** /indexes/{indexId} | Get Index by indexId
*IndexApi* | [**get_index_by_object_id**](docs/IndexApi.md#get_index_by_object_id) | **GET** /indexes/objects/{objectId} | Get Index by objectId


## Documentation For Models

 - [AddIndexResponse](docs/AddIndexResponse.md)
 - [AddIndexResponseData](docs/AddIndexResponseData.md)
 - [GetIndexResponse](docs/GetIndexResponse.md)
 - [Index](docs/Index.md)


## Documentation For Authorization


## api_key

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: HTTP header


## Author

master@bluehack.net

